==> checkmysql-0.1.6.tar.gz: checkmysql-0.1.6/setup.py <==
# coding: utf-8

"""
Check MySQL cli interface
"""
from setuptools import find_packages, setup

dependencies = ['typer', 'PyMySQL', 'rich']

setup(
    name='checkmysql',
    version='0.1.6',
    url='https://github.com/odgon/checkmysql',
    license='BSD',
    author='Lucian BLETAN',
    author_email='neuraluc@gmail.com',
    description='Check MySQL cli interface',
    long_description=__doc__,
    packages=find_packages(exclude=['tests']),
    include_package_data=True,
    zip_safe=False,
    platforms='any',
    install_requires=dependencies,
    entry_points={
        'console_scripts': [
            'checkmysql = checkmysql.cli:app',
        ],
    },
    classifiers=[
        # As from http://pypi.python.org/pypi?%3Aaction=list_classifiers
        # 'Development Status :: 1 - Planning',
        # 'Development Status :: 2 - Pre-Alpha',
        # 'Development Status :: 3 - Alpha',
        'Development Status :: 4 - Beta',
        # 'Development Status :: 5 - Production/Stable',
        # 'Development Status :: 6 - Mature',
        # 'Development Status :: 7 - Inactive',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: POSIX',
        'Operating System :: MacOS',
        'Operating System :: Unix',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 3',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ]
)

==> checkmysql-0.1.7.tar.gz: checkmysql-0.1.7/setup.py <==
# coding: utf-8

"""
Check MySQL cli interface
"""
from setuptools import find_packages, setup

dependencies = ['typer', 'PyMySQL', 'rich']

setup(
    name='checkmysql',
    version='0.1.7',
    url='https://github.com/odgon/checkmysql',
    license='BSD',
    author='Lucian BLETAN',
    author_email='neuraluc@gmail.com',
    description='Check MySQL cli interface',
    long_description=__doc__,
    packages=find_packages(exclude=['tests']),
    include_package_data=True,
    zip_safe=False,
    platforms='any',
    install_requires=dependencies,
    entry_points={
        'console_scripts': [
            'checkmysql = checkmysql.cli:app',
        ],
    },
    classifiers=[
        # As from http://pypi.python.org/pypi?%3Aaction=list_classifiers
        # 'Development Status :: 1 - Planning',
        # 'Development Status :: 2 - Pre-Alpha',
        # 'Development Status :: 3 - Alpha',
        'Development Status :: 4 - Beta',
        # 'Development Status :: 5 - Production/Stable',
        # 'Development Status :: 6 - Mature',
        # 'Development Status :: 7 - Inactive',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: POSIX',
        'Operating System :: MacOS',
        'Operating System :: Unix',
        'Programming Language :: Python',
        # 'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 3',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ]
)
